@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "bilibili" "1.0.0"
+(define-package "bilibili" "20250727.348"
   "Watch videos of BiliBili (哔哩哔哩) in org mode."
   '((emacs "29.1")
     (org   "9.0")
